@@ -7,7 +7,7 @@ use Path::Tiny qw( path );
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Legacy alien for libarchive
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 
 sub new
@@ -18,14 +18,14 @@ sub new
 
 sub cflags
 {
-  wantarray
+  wantarray   ## no critic (Freenode::Wantarray)
     ? shellwords(Alien::Libarchive3->cflags)
     : Alien::Libarchive3->cflags;
 }
 
 sub libs
 {
-  wantarray
+  wantarray   ## no critic (Freenode::Wantarray)
     ? shellwords(Alien::Libarchive3->libs)
     : Alien::Libarchive3->libs;
 }
@@ -33,7 +33,7 @@ sub libs
 sub dlls
 {
   my @libs = Alien::Libarchive3->dynamic_libs;
-  wantarray ? @libs : $libs[0];
+  wantarray ? @libs : $libs[0];   ## no critic (Freenode::Wantarray)
 }
 
 sub version
@@ -94,7 +94,7 @@ Alien::Libarchive - Legacy alien for libarchive
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
